@@ -39,10 +39,10 @@
 // constants
 
 
-static const char * const Version = "1.4.56b";
+static const char * const Version = "1.4.58b";
 static const char * const HelpMessage = "\
 SYNTAX\n\
-* polyglot [configfile] [-noini] [-ec engine] [-ed enginedirectory] [-en enginename] [-log] [-lf logfile] [-hash value] [-bk book] [-pg <name>=<value>]* [-uci <name>=<value>]*\n\
+* polyglot [configfile] [-noini] [-ec engine] [-ed enginedirectory] [-en enginename] [-log true/false] [-lf logfile] [-pg <name>=<value>]* [-uci <name>=<value>]*\n\
 * polyglot make-book [-pgn inputfile] [-bin outputfile] [-max-ply ply] [-min-game games] [-min-score score] [-only-white] [-only-black] [-uniform]\n\
 * polyglot merge-book -in1 inputfile1 -in2 inputfile2 [-out outputfile]\n\
 * polyglot info-book [-bin inputfile] [-exact]\n\
@@ -639,7 +639,6 @@ void quit() {
         stop_search();
 	Engine->pipex->quit_pending=TRUE;
         engine_send(Engine,"quit");
-        my_log("POLYGLOT Closing engine\n");
         engine_close(Engine);
         
     }
